﻿using System;
using System.Collections.ObjectModel;
using System.Windows.Forms;
using wsUsbDevice;

namespace UsgControl_602C
{
    public partial class UsgControl : Form
    {
        USG602C device = new USG602C();
        Collection<string> ports = new Collection<string>();
        public UsgControl()
        {
            InitializeComponent();

            ports = device.GetActivePorts();
            foreach(string port in ports)
            {
                ComboBox_Port.Items.Add(port);
            }
            if (ports.Count > 0)
                ComboBox_Port.SelectedIndex = 0;
        }

        private void ComboBox_Port_SelectedIndexChanged(object sender, EventArgs e)
        {
            //Arrange Port
            device.PortName = ComboBox_Port.Text;

            //Open Device
            if(!device.Open())
            {
                MessageBox.Show("Fail To Open Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            //Query Device SN
            if (!device.QueryDevice())
            {
                MessageBox.Show("Fail To Query Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }
            labStatus.Text = device.DeviceInfo +";" +device.DeviceSN;
            numeric_Frquency.Value = device.Frequency;
            numeric_Power.Value = (decimal)device.Power;
            checkBox_Output.Checked = device.Output;
            checkBox_ExRef.Checked = device.ExtREF;

            //Close Device
            if (!device.Close())
            {
                MessageBox.Show("Fail To Close Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }
        }

        private void numeric_Frquency_ValueChanged(object sender, EventArgs e)
        {
            //Open Device
            if (!device.Open())
            {
                MessageBox.Show("Fail To Open Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            //Change Frequency
            device.Frequency = (UInt64)numeric_Frquency.Value;
            if(!device.SetFrequency())
            {
                MessageBox.Show("Fail To Set Frequency.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            if (device.Output)
                if (!device.QueryLockStatus())
                {
                    MessageBox.Show("Device Frequency Is NOT Locked.", "USG602C",
                        MessageBoxButtons.OK, MessageBoxIcon.Hand);
                    return;
                }

            //Close Device
            if (!device.Close())
            {
                MessageBox.Show("Fail To Close Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }
        }

        private void numeric_Power_ValueChanged(object sender, EventArgs e)
        {
            //Open Device
            if (!device.Open())
            {
                MessageBox.Show("Fail To Open Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            //Change Power
            device.Power = (double )numeric_Power.Value;
            if (!device.SetPower())
            {
                MessageBox.Show("Fail To Set Power.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            //Close Device
            if (!device.Close())
            {
                MessageBox.Show("Fail To Close Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }
        }
        private void checkBox_Output_CheckedChanged(object sender, EventArgs e)
        {
            //Open Device
            if (!device.Open())
            {
                MessageBox.Show("Fail To Open Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            //Set Output
            device.Output = checkBox_Output.Checked;
            if (!device.SetOutput())
            {
                MessageBox.Show("Fail To Set Output.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            //Close Device
            if (!device.Close())
            {
                MessageBox.Show("Fail To Close Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }
        }

        private void checkBox_ExRef_CheckedChanged(object sender, EventArgs e)
        {
            //Open Device
            if (!device.Open())
            {
                MessageBox.Show("Fail To Open Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            //Set Ext REF
            device.ExtREF = checkBox_ExRef.Checked;
            if (!device.SetExtRef())
            {
                MessageBox.Show("Fail To Set Ext Ref.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }

            //Close Device
            if (!device.Close())
            {
                MessageBox.Show("Fail To Close Device.", "USG602C",
                     MessageBoxButtons.OK, MessageBoxIcon.Hand);
                return;
            }
        }

        
    }
}
